import React, { useState, useEffect } from "react"
import Taro from "@tarojs/taro";
import { View, Input, Swiper, Image, SwiperItem, Text, ScrollView } from "@tarojs/components"
import positionImg from '@/assets/comm/position.png'
import searchImg from '@/assets/comm/search.png'
import orderImg from '@/assets/comm/orderList.png'
import LoginModel from "@/components/LoginModel";
import Footer from "@/components/Footer";
import MyCard from "@/components/MyCard";
import { useModel } from "@/store";


import { getBannerList } from "@/services/banner";
import './style.less'


export default (props) => {
  const {handleMore,handleDetail}=props
  const [imgList, setImgList] = useState([])  
  const [show, setShow] = useState(false)
  const [path, setPath] = useState()
  const { person } = useModel('person')

  const handleSearch = (e) => {
    console.log(e.detail.value)
  }
  
  useEffect(() => {
    getBannerList({ position: 'bannerWorker' })
      .then(res => {
        setImgList(res)
      }).catch(err => {
        Taro.showToast({
          title: '网络异常, 请刷新小程序重试',
          icon: 'none',
        })
      })
  }, [])
  return (
    <View className='orderIndex'>
      {
        show && <LoginModel path={path} close={() => setShow(false)} />
      }
      <View className='top'>
        <View className='left'>
          <Image src={positionImg} className='pImg' />
          <Text>邓州市</Text>
          <View className='icon' />
        </View>
        <View className='searchClass'>
          <Input type='text' className='searchInput' onBlur={handleSearch} placeholder='搜索关键字查询订单' />
          <Image src={searchImg} className='searchImg' />
        </View>
      </View>
      <ScrollView scrollY style={{ height: 'calc(100% - 50px)' }}>
        <View>
          <Swiper
            circular
            autoplay
            className='swiper'
          >
            {imgList.map((item, inx) => (
              <SwiperItem key={inx}>
                <Image src={item.thumb} mode='widthFix' className='storeImage' />
              </SwiperItem>
            ))}
          </Swiper>
        </View>
        <View className='orderList'>
          <View className='head'>
            <Image className='headIcon' src={orderImg} />
            <Text className='title'>订单列表</Text>
            <Text className='more' onClick={handleMore}>更多>></Text>
          </View>

          <MyCard order handleDetail={handleDetail} />
          <MyCard order handleDetail={handleDetail} />
          <Footer />
        </View>
      </ScrollView>
    </View>
  )
}